# Telegram Chat

Holds basic information about a Telegram chat:

* id
* title (if it is not a private chat)
* username (if it has one)
* type (one of <i>private, group, supergroup, channel</i>)

This model can be modified to store more information if needed.